import 'package:nudge_leaderboard_ui/features/leaderboard/data/datasources/createuser.dart';
import 'package:nudge_leaderboard_ui/features/leaderboard/data/models/create_user.dart';
import 'package:nudge_leaderboard_ui/features/leaderboard/presentation/widgets/leaderboard_nodata.dart';
import 'package:nudge_leaderboard_ui/features/leaderboard/presentation/widgets/leaderboard_scoredata.dart';

import '../../data/models/get_all_leaderboard_rewards.dart';
import '../../data/models/get_nudge_leaderboard.dart';
import '../widgets/appbar/leaderboard_appbar.dart';
import 'package:flutter/material.dart';

class LeaderboardScreen extends StatefulWidget {
  final String token;
  final String? rewardID;
  final String? externalID;
  final Map<String, dynamic>? props;

  const LeaderboardScreen(
      {super.key,
      required this.token,
      this.rewardID,
      required this.externalID,
      this.props});
  @override
  State<LeaderboardScreen> createState() =>
      // ignore: no_logic_in_create_state
      _LeaderboardScreenState(rewardID: rewardID);
}

class _LeaderboardScreenState extends State<LeaderboardScreen> {
  String? rewardID;
  bool isLoading = false;
  int currentItemCount = 10;
  final int increment = 10;
  GetNudgeLeaderboard? nudgeleaderboarddata;
  GetAllLeaderboardRewards? allLeaderboardRewardsdata;
  CreateUser? userData;

  _LeaderboardScreenState({
    this.rewardID,
  });

  @override
  void initState() {
    super.initState();
    fetchRewardsData().then((_) {
      if (rewardID?.isEmpty == true) {
        fetchLeaderboard();
      } else {
        fetchLeaderboardonReward(rewardID);
      }
    });
  }

  Future<void> fetchRewardsData() async {
    try {
      CreateUser createuser = await createuserrequest(
        widget.token,
        widget.externalID,
        props: widget.props,
      );
      setState(() {
        userData = createuser;
      });
    } catch (error) {
      debugPrint('Error: $error');
    }
  }

  Future<void> fetchLeaderboard() async {
    try {
      GetNudgeLeaderboard fetchedRewardsLeaderboard = await getnudgeleaderboard(
        userData?.data.token,
        'https://pointsystem.api.nudgenow.com/api/v1/users/u/get/leaderboard/score',
      );
      setState(() {
        nudgeleaderboarddata = fetchedRewardsLeaderboard;
      });
    } catch (error) {
      debugPrint('Error: $error');
    }
  }

  Future<void> fetchLeaderboardonReward(String? rewardID) async {
    try {
      GetNudgeLeaderboard fetchedRewardsLeaderboard = await getnudgeleaderboard(
        userData?.data.token,
        'https://pointsystem.api.nudgenow.com/api/v1/users/u/get/leaderboard/reward/$rewardID',
      );
      setState(() {
        nudgeleaderboarddata = fetchedRewardsLeaderboard;
      });
    } catch (error) {
      debugPrint('Error: $error');
    }
  }

  Future<void> loadMoreData() async {
    if (isLoading) {
      return;
    }
    setState(() {
      isLoading = true;
    });
    await Future.delayed(
      const Duration(
        seconds: 1,
      ),
    );

    if (currentItemCount + increment <=
        (nudgeleaderboarddata?.data.users.length ?? 0)) {
      currentItemCount += increment;
    } else {
      currentItemCount = (nudgeleaderboarddata?.data.users.length ?? 0);
    }
    setState(() {
      isLoading = false;
    });
  }

  @override
  Widget build(BuildContext context) {
    if (nudgeleaderboarddata == null) {
      return Scaffold(
        backgroundColor: const Color.fromRGBO(49, 162, 215, 1),
        appBar: const LeaderboardAppBar(),
        body: Center(
          child: Column(
            mainAxisAlignment: MainAxisAlignment.center,
            children: [
              _buildSubtitle("Loading..."),
              const SizedBox(height: 10),
              const CircularProgressIndicator(
                strokeWidth: 6,
                color: Colors.white,
              ),
            ],
          ),
        ),
      );
    } else if (nudgeleaderboarddata?.data.users.isEmpty ?? true) {
      return const LeaderboardNoData();
    } else {
      return LeaderboardDataScore(
        nudgeleaderboarddata: nudgeleaderboarddata,
        currentItemCount: currentItemCount,
        loadMoreData: loadMoreData,
      );
    }
  }
}

Widget _buildSubtitle(String title) {
  return Container(
    padding: const EdgeInsets.only(
      top: 24,
      bottom: 16,
    ),
    child: Text(
      title,
      style: const TextStyle(
        fontSize: 20,
        color: Colors.white,
      ),
    ),
  );
}
