import 'package:flutter/material.dart';

class LeaderboardRankers extends StatelessWidget {
  final String nameRank1;
  final String nameRank2;
  final String nameRank3;
  final int pointsRank1;
  final int pointsRank2;
  final int pointsRank3;

  const LeaderboardRankers({
    Key? key,
    required this.nameRank1,
    required this.nameRank2,
    required this.nameRank3,
    required this.pointsRank1,
    required this.pointsRank2,
    required this.pointsRank3,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return Row(
      mainAxisAlignment: MainAxisAlignment.spaceBetween,
      crossAxisAlignment: CrossAxisAlignment.end,
      children: [
        RankerContainer(
          height: MediaQuery.of(context).size.height * 0.36,
          rank: 2,
          name: nameRank2,
          points: pointsRank2,
          containerwidth: 3.1,
          imageScale: MediaQuery.of(context).size.width * 0.004,
        ),
        RankerContainer(
          height: MediaQuery.of(context).size.height * 0.4,
          rank: 1,
          name: nameRank1,
          points: pointsRank1,
          containerwidth: 2.8,
          imageScale: MediaQuery.of(context).size.width * 0.004,
        ),
        RankerContainer(
          height: MediaQuery.of(context).size.height * 0.33,
          rank: 3,
          name: nameRank3,
          points: pointsRank3,
          containerwidth: 3.2,
          imageScale: MediaQuery.of(context).size.width * 0.004,
        ),
      ],
    );
  }
}

class RankerContainer extends StatelessWidget {
  final double height;
  final String name;
  final int points;
  final int rank;
  final double containerwidth;
  final double imageScale;

  const RankerContainer({
    super.key,
    required this.height,
    required this.name,
    required this.points,
    required this.rank,
    required this.containerwidth,
    required this.imageScale,
  });

  @override
  Widget build(BuildContext context) {
    return SizedBox(
      width: MediaQuery.of(context).size.width / containerwidth,
      height: height,
      child: Stack(
        alignment: Alignment.topCenter,
        children: [
          Positioned(
            top: 20.0,
            child: Container(
              width: MediaQuery.of(context).size.width / (containerwidth + 0.2),
              height: height,
              decoration: BoxDecoration(
                border: Border.all(
                  color: const Color.fromRGBO(136, 217, 255, 1),
                  width: 1.0,
                ),
                borderRadius: const BorderRadius.only(
                  topLeft: Radius.circular(20),
                  topRight: Radius.circular(20),
                ),
              ),
            ),
          ),
          Column(
            children: [
              const CircularAvatarContainer(),
              const SizedBox(
                height: 5,
              ),
              Text(
                name,
                style: const TextStyle(
                  color: Colors.white,
                  fontSize: 12,
                  fontWeight: FontWeight.w700,
                ),
                overflow: TextOverflow.ellipsis,
              ),
              const SizedBox(
                height: 6,
              ),
              PointsContainer(
                points: points,
              ),
              const SizedBox(
                height: 15,
              ),
              RankStarContainer(
                imageScale: imageScale,
                rank: rank,
              ),
            ],
          ),
        ],
      ),
    );
  }
}

class CircularAvatarContainer extends StatelessWidget {
  const CircularAvatarContainer({super.key});

  @override
  Widget build(BuildContext context) {
    return Container(
      width: 50.0,
      height: 50.0,
      decoration: BoxDecoration(
        shape: BoxShape.circle,
        border: Border.all(
          color: Colors.blue,
          width: 2.0,
        ),
      ),
      child: const CircleAvatar(
        backgroundColor: Colors.grey,
        radius: 24.0,
        backgroundImage: AssetImage(
          'lib/core/assets/circularavatar.png',
        ),
      ),
    );
  }
}

class PointsContainer extends StatelessWidget {
  final int points;

  const PointsContainer({
    super.key,
    required this.points,
  });

  @override
  Widget build(BuildContext context) {
    return Container(
      decoration: const BoxDecoration(
        color: Color.fromRGBO(35, 146, 198, 1),
        borderRadius: BorderRadius.all(
          Radius.circular(10),
        ),
      ),
      child: Padding(
        padding: const EdgeInsets.all(8.0),
        child: Text(
          '$points points',
          style: const TextStyle(
            color: Colors.white,
            fontSize: 12,
            fontWeight: FontWeight.w500,
          ),
          overflow: TextOverflow.ellipsis,
        ),
      ),
    );
  }
}

class RankStarContainer extends StatelessWidget {
  final int rank;
  final double imageScale;

  const RankStarContainer({
    super.key,
    required this.rank,
    required this.imageScale,
  });

  @override
  Widget build(BuildContext context) {
    return Image.asset(
      'lib/core/assets/Rank$rank.png',
      scale: imageScale,
    );
  }
}
