import 'package:nudge_leaderboard_ui/features/leaderboard/data/models/get_nudge_leaderboard.dart';
import 'package:nudge_leaderboard_ui/features/leaderboard/presentation/widgets/appbar/leaderboard_appbar.dart';
import 'package:nudge_leaderboard_ui/features/leaderboard/presentation/widgets/leaderboard_rankers_container.dart';
import 'package:nudge_leaderboard_ui/features/leaderboard/presentation/widgets/rank_container.dart';
import 'package:lazy_load_scrollview/lazy_load_scrollview.dart';
import 'package:flutter/material.dart';

class LeaderboardDataScore extends StatelessWidget {
  final GetNudgeLeaderboard? nudgeleaderboarddata;
  final int currentItemCount;
  final VoidCallback loadMoreData;

  const LeaderboardDataScore({
    super.key,
    required this.nudgeleaderboarddata,
    required this.currentItemCount,
    required this.loadMoreData,
  });
  @override
  Widget build(BuildContext context) {
    return Scaffold(
      backgroundColor: const Color.fromRGBO(49, 162, 215, 1),
      appBar: const LeaderboardAppBar(),
      body: Column(
        children: [
          const SizedBox(height: 10),
          Container(
            width: double.infinity,
            decoration: const BoxDecoration(
              color: Color.fromRGBO(49, 162, 215, 1),
              borderRadius: BorderRadius.only(
                topLeft: Radius.circular(20),
                topRight: Radius.circular(20),
              ),
            ),
            child: Row(
              children: [
                LeaderboardRankers(
                  nameRank1: nudgeleaderboarddata?.data.users[0].userId.name ??
                      'Loading...',
                  pointsRank1: nudgeleaderboarddata?.data.users[0].score ?? 0,
                  nameRank2: nudgeleaderboarddata?.data.users[1].userId.name ??
                      'Loading...',
                  pointsRank2: nudgeleaderboarddata?.data.users[1].score ?? 0,
                  nameRank3: nudgeleaderboarddata?.data.users[2].userId.name ??
                      'Loading...',
                  pointsRank3: nudgeleaderboarddata?.data.users[2].score ?? 0,
                ),
              ],
            ),
          ),
          Container(
            width: double.infinity,
            decoration: const BoxDecoration(
              color: Color.fromRGBO(246, 247, 250, 1),
              borderRadius: BorderRadius.only(
                topLeft: Radius.circular(20),
                topRight: Radius.circular(20),
              ),
            ),
            child: const Headers(),
          ),
          Expanded(
            child: Container(
              decoration: const BoxDecoration(
                color: Color.fromRGBO(246, 247, 250, 1),
              ),
              child: nudgeleaderboarddata == null
                  ? const Center(
                      child: CircularProgressIndicator(
                        strokeWidth: 6,
                        color: Color.fromRGBO(49, 162, 215, 1),
                      ),
                    )
                  : LazyLoadScrollView(
                      onEndOfPage: () => loadMoreData(),
                      child: SingleChildScrollView(
                        child: Column(
                          children: [
                            RankContainer(
                              points:
                                  nudgeleaderboarddata?.data.user.score ?? 0,
                              name:
                                  nudgeleaderboarddata?.data.user.userId.name ??
                                      'loading....',
                              rank: nudgeleaderboarddata?.data.rank ?? 0,
                            ),
                            for (int index = 0;
                                index < currentItemCount &&
                                    index <
                                        (nudgeleaderboarddata
                                                ?.data.users.length ??
                                            0);
                                index++)
                              RankContainer(
                                points: nudgeleaderboarddata
                                        ?.data.users[index].score ??
                                    0,
                                name: nudgeleaderboarddata
                                        ?.data.users[index].userId.name ??
                                    'Loading...',
                                rank: index + 1,
                              ),
                          ],
                        ),
                      ),
                    ),
            ),
          ),
        ],
      ),
    );
  }
}

class Headers extends StatelessWidget {
  const Headers({super.key});

  @override
  Widget build(BuildContext context) {
    return const Padding(
      padding: EdgeInsets.only(left: 24.0, top: 16, right: 24, bottom: 8),
      child: Row(
        mainAxisAlignment: MainAxisAlignment.spaceBetween,
        children: [
          Text(
            'Rank',
            style: TextStyle(
              color: Colors.black,
              fontSize: 16,
              fontWeight: FontWeight.normal,
            ),
          ),
          Text(
            'Name',
            style: TextStyle(
              color: Colors.black,
              fontSize: 16,
              fontWeight: FontWeight.normal,
            ),
          ),
          Text(
            'Points',
            style: TextStyle(
              color: Colors.black,
              fontSize: 16,
              fontWeight: FontWeight.normal,
            ),
          ),
        ],
      ),
    );
  }
}
